==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Cancellare le statistiche', # MODIF

	// I
	'icone_evolution_visites' => 'Evoluzione delle visite<br />@visites@ visite',
	'icone_repartition_actuelle' => 'Mostra la ripartizione attuale',
	'icone_repartition_visites' => 'Distribuzione delle visite',
	'icone_statistiques_visites' => 'Statistiche delle visite',
	'info_affichier_visites_articles_plus_visites' => 'Mostra le visite per <b>gli articoli più letti dall’inaugurazione del sito:</b>',
	'info_comment_lire_tableau' => 'Come leggere questa tabella',
	'info_forum_statistiques' => 'Statistiche delle visite',
	'info_popularite_2' => 'popolarità del sito: ',
	'info_popularite_3' => 'popolarità: @popularite@; visite: @visites@',
	'info_popularite_5' => 'popolarità:',
	'info_question_vignettes_referer' => 'Quando si consultano le statistiche è possibile visualizzare delle anteprime dei siti di origine delle visite',
	'info_question_vignettes_referer_oui' => 'Visualizzare le catture di schermo dei siti di origine delle visite',
	'info_visites' => 'visite:',
	'info_visites_plus_populaires' => 'Pubblica le visite per <b>gli articoli più popolari </b> e per <b>gli ultimi articoli pubblicati:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestisci le statistiche', # MODIF

	// O
	'onglet_origine_visites' => 'Origine delle visite',
	'onglet_repartition_debut' => 'dall’inizio',
	'onglet_repartition_lang' => 'Suddivisione per lingua',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Questo comando cancella tutti i dati collegati alle statistiche delle visite al sito, comprese la popolarità degli articoli.',
	'texte_comment_lire_tableau' => 'Il posizionamento dell’articolo,
nella classifica per popolarità, è indicato qui
sopra. La popolarità dell’articolo (una stima del
numero di visite quotidiane che riceverà rimanendo costante il ritmo attuale di
consultazione) e il numero di visite ricevute dall’inizio,
sono visualizzati nel commento che appare
quando si passa con il mouse sopra al titolo.',
	'texte_signification' => 'Le barre più scure rappresentano le entrate accumulate (per il totale delle sottorubriche), le barre più chiare il numero di visite per ogni rubrica.',
	'titre_evolution_visite' => 'Evoluzione delle visite',
	'titre_liens_entrants' => 'I link odierni al tuo sito',
	'titre_page_statistiques' => 'Statistiche per rubrica',
	'titre_page_statistiques_visites' => 'Statistiche delle visite'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Cancellare le statistiche', # MODIF

	// I
	'icone_evolution_visites' => 'Evoluzione delle visite<br />@visites@ visite',
	'icone_repartition_actuelle' => 'Mostra la ripartizione attuale',
	'icone_repartition_visites' => 'Distribuzione delle visite',
	'icone_statistiques_visites' => 'Statistiche delle visite',
	'info_affichier_visites_articles_plus_visites' => 'Mostra le visite per <b>gli articoli più letti dall’inaugurazione del sito:</b>',
	'info_comment_lire_tableau' => 'Come leggere questa tabella',
	'info_forum_statistiques' => 'Statistiche delle visite',
	'info_popularite_2' => 'popolarità del sito: ',
	'info_popularite_3' => 'popolarità: @popularite@; visite: @visites@',
	'info_popularite_5' => 'popolarità:',
	'info_question_vignettes_referer' => 'Quando si consultano le statistiche è possibile visualizzare delle anteprime dei siti di origine delle visite', # MODIF
	'info_question_vignettes_referer_oui' => 'Visualizzare le catture di schermo dei siti di origine delle visite',
	'info_visites' => 'visite:',
	'info_visites_plus_populaires' => 'Pubblica le visite per <b>gli articoli più popolari </b> e per <b>gli ultimi articoli pubblicati:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestisci le statistiche', # MODIF

	// O
	'onglet_origine_visites' => 'Origine delle visite',
	'onglet_repartition_debut' => 'dall’inizio',
	'onglet_repartition_lang' => 'Suddivisione per lingua',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Questo comando cancella tutti i dati collegati alle statistiche delle visite al sito, comprese la popolarità degli articoli.',
	'texte_comment_lire_tableau' => 'Il posizionamento dell’articolo,
nella classifica per popolarità, è indicato qui
sopra. La popolarità dell’articolo (una stima del
numero di visite quotidiane che riceverà rimanendo costante il ritmo attuale di
consultazione) e il numero di visite ricevute dall’inizio,
sono visualizzati nel commento che appare
quando si passa con il mouse sopra al titolo.',
	'texte_signification' => 'Le barre più scure rappresentano le entrate accumulate (per il totale delle sottorubriche), le barre più chiare il numero di visite per ogni rubrica.',
	'titre_evolution_visite' => 'Evoluzione delle visite',
	'titre_liens_entrants' => 'I link odierni al tuo sito',
	'titre_page_statistiques' => 'Statistiche per rubrica',
	'titre_page_statistiques_visites' => 'Statistiche delle visite'
);
